@@ -5,8 +5,9 @@ from scrapy.crawler import CrawlerProcess
 class NoRequestsSpider(scrapy.Spider):
     name = "no_request"
 
-    def start_requests(self):
-        return []
+    async def start(self):
+        return
+        yield
 
 
 process = CrawlerProcess(settings={})
