@@ -1,5 +1,3 @@
-from unittest import TestCase
-
 from scrapy.downloadermiddlewares.defaultheaders import DefaultHeadersMiddleware
 from scrapy.http import Request
 from scrapy.spiders import Spider
@@ -7,7 +5,7 @@ from scrapy.utils.python import to_bytes
 from scrapy.utils.test import get_crawler
 
 
-class TestDefaultHeadersMiddleware(TestCase):
+class TestDefaultHeadersMiddleware:
     def get_defaults_spider_mw(self):
         crawler = get_crawler(Spider)
         spider = crawler._create_spider("foo")
@@ -21,15 +19,15 @@ class TestDefaultHeadersMiddleware(TestCase):
         defaults, spider, mw = self.get_defaults_spider_mw()
         req = Request("http://www.scrapytest.org")
         mw.process_request(req, spider)
-        self.assertEqual(req.headers, defaults)
+        assert req.headers == defaults
 
     def test_update_headers(self):
         defaults, spider, mw = self.get_defaults_spider_mw()
         headers = {"Accept-Language": ["es"], "Test-Header": ["test"]}
         bytes_headers = {b"Accept-Language": [b"es"], b"Test-Header": [b"test"]}
         req = Request("http://www.scrapytest.org", headers=headers)
-        self.assertEqual(req.headers, bytes_headers)
+        assert req.headers == bytes_headers
 
         mw.process_request(req, spider)
         defaults.update(bytes_headers)
-        self.assertEqual(req.headers, defaults)
+        assert req.headers == defaults
