@@ -1,6 +1,6 @@
 import logging
-import unittest
 
+import pytest
 from testfixtures import LogCapture
 from twisted.internet import defer
 from twisted.internet.error import (
@@ -20,8 +20,8 @@ from scrapy.spiders import Spider
 from scrapy.utils.test import get_crawler
 
 
-class RetryTest(unittest.TestCase):
-    def setUp(self):
+class TestRetry:
+    def setup_method(self):
         self.crawler = get_crawler(Spider)
         self.spider = self.crawler._create_spider("foo")
         self.mw = RetryMiddleware.from_crawler(self.crawler)
@@ -69,12 +69,12 @@ class RetryTest(unittest.TestCase):
         # first retry
         req = self.mw.process_response(req, rsp, self.spider)
         assert isinstance(req, Request)
-        self.assertEqual(req.meta["retry_times"], 1)
+        assert req.meta["retry_times"] == 1
 
         # second retry
         req = self.mw.process_response(req, rsp, self.spider)
         assert isinstance(req, Request)
-        self.assertEqual(req.meta["retry_times"], 2)
+        assert req.meta["retry_times"] == 2
 
         # discard it
         assert self.mw.process_response(req, rsp, self.spider) is rsp
@@ -114,7 +114,7 @@ class RetryTest(unittest.TestCase):
     def test_exception_to_retry_added(self):
         exc = ValueError
         settings_dict = {
-            "RETRY_EXCEPTIONS": list(RETRY_EXCEPTIONS) + [exc],
+            "RETRY_EXCEPTIONS": [*RETRY_EXCEPTIONS, exc],
         }
         crawler = get_crawler(Spider, settings_dict=settings_dict)
         mw = RetryMiddleware.from_crawler(crawler)
@@ -128,19 +128,19 @@ class RetryTest(unittest.TestCase):
         # first retry
         req = mw.process_exception(req, exception, self.spider)
         assert isinstance(req, Request)
-        self.assertEqual(req.meta["retry_times"], 1)
+        assert req.meta["retry_times"] == 1
 
         # second retry
         req = mw.process_exception(req, exception, self.spider)
         assert isinstance(req, Request)
-        self.assertEqual(req.meta["retry_times"], 2)
+        assert req.meta["retry_times"] == 2
 
         # discard it
         req = mw.process_exception(req, exception, self.spider)
-        self.assertEqual(req, None)
+        assert req is None
 
 
-class MaxRetryTimesTest(unittest.TestCase):
+class TestMaxRetryTimes:
     invalid_url = "http://www.scrapytest.org/invalid_url"
 
     def get_spider_and_middleware(self, settings=None):
@@ -265,16 +265,16 @@ class MaxRetryTimesTest(unittest.TestCase):
         spider = spider or self.spider
         middleware = middleware or self.mw
 
-        for i in range(0, max_retry_times):
+        for i in range(max_retry_times):
             req = middleware.process_exception(req, exception, spider)
             assert isinstance(req, Request)
 
         # discard it
         req = middleware.process_exception(req, exception, spider)
-        self.assertEqual(req, None)
+        assert req is None
 
 
-class GetRetryRequestTest(unittest.TestCase):
+class TestGetRetryRequest:
     def get_spider(self, settings=None):
         crawler = get_crawler(Spider, settings or {})
         return crawler._create_spider("foo")
@@ -287,15 +287,15 @@ class GetRetryRequestTest(unittest.TestCase):
                 request,
                 spider=spider,
             )
-        self.assertIsInstance(new_request, Request)
-        self.assertNotEqual(new_request, request)
-        self.assertEqual(new_request.dont_filter, True)
+        assert isinstance(new_request, Request)
+        assert new_request != request
+        assert new_request.dont_filter
         expected_retry_times = 1
-        self.assertEqual(new_request.meta["retry_times"], expected_retry_times)
-        self.assertEqual(new_request.priority, -1)
+        assert new_request.meta["retry_times"] == expected_retry_times
+        assert new_request.priority == -1
         expected_reason = "unspecified"
         for stat in ("retry/count", f"retry/reason_count/{expected_reason}"):
-            self.assertEqual(spider.crawler.stats.get_value(stat), 1)
+            assert spider.crawler.stats.get_value(stat) == 1
         log.check_present(
             (
                 "scrapy.downloadermiddlewares.retry",
@@ -315,8 +315,8 @@ class GetRetryRequestTest(unittest.TestCase):
                 spider=spider,
                 max_retry_times=max_retry_times,
             )
-        self.assertEqual(new_request, None)
-        self.assertEqual(spider.crawler.stats.get_value("retry/max_reached"), 1)
+        assert new_request is None
+        assert spider.crawler.stats.get_value("retry/max_reached") == 1
         failure_count = max_retry_times + 1
         expected_reason = "unspecified"
         log.check_present(
@@ -337,15 +337,15 @@ class GetRetryRequestTest(unittest.TestCase):
                 spider=spider,
                 max_retry_times=1,
             )
-        self.assertIsInstance(new_request, Request)
-        self.assertNotEqual(new_request, request)
-        self.assertEqual(new_request.dont_filter, True)
+        assert isinstance(new_request, Request)
+        assert new_request != request
+        assert new_request.dont_filter
         expected_retry_times = 1
-        self.assertEqual(new_request.meta["retry_times"], expected_retry_times)
-        self.assertEqual(new_request.priority, -1)
+        assert new_request.meta["retry_times"] == expected_retry_times
+        assert new_request.priority == -1
         expected_reason = "unspecified"
         for stat in ("retry/count", f"retry/reason_count/{expected_reason}"):
-            self.assertEqual(spider.crawler.stats.get_value(stat), 1)
+            assert spider.crawler.stats.get_value(stat) == 1
         log.check_present(
             (
                 "scrapy.downloadermiddlewares.retry",
@@ -367,16 +367,16 @@ class GetRetryRequestTest(unittest.TestCase):
                     spider=spider,
                     max_retry_times=max_retry_times,
                 )
-            self.assertIsInstance(new_request, Request)
-            self.assertNotEqual(new_request, request)
-            self.assertEqual(new_request.dont_filter, True)
+            assert isinstance(new_request, Request)
+            assert new_request != request
+            assert new_request.dont_filter
             expected_retry_times = index + 1
-            self.assertEqual(new_request.meta["retry_times"], expected_retry_times)
-            self.assertEqual(new_request.priority, -expected_retry_times)
+            assert new_request.meta["retry_times"] == expected_retry_times
+            assert new_request.priority == -expected_retry_times
             expected_reason = "unspecified"
             for stat in ("retry/count", f"retry/reason_count/{expected_reason}"):
                 value = spider.crawler.stats.get_value(stat)
-                self.assertEqual(value, expected_retry_times)
+                assert value == expected_retry_times
             log.check_present(
                 (
                     "scrapy.downloadermiddlewares.retry",
@@ -392,8 +392,8 @@ class GetRetryRequestTest(unittest.TestCase):
                 spider=spider,
                 max_retry_times=max_retry_times,
             )
-        self.assertEqual(new_request, None)
-        self.assertEqual(spider.crawler.stats.get_value("retry/max_reached"), 1)
+        assert new_request is None
+        assert spider.crawler.stats.get_value("retry/max_reached") == 1
         failure_count = max_retry_times + 1
         expected_reason = "unspecified"
         log.check_present(
@@ -407,7 +407,7 @@ class GetRetryRequestTest(unittest.TestCase):
 
     def test_no_spider(self):
         request = Request("https://example.com")
-        with self.assertRaises(TypeError):
+        with pytest.raises(TypeError):
             get_retry_request(request)  # pylint: disable=missing-kwoa
 
     def test_max_retry_times_setting(self):
@@ -418,7 +418,7 @@ class GetRetryRequestTest(unittest.TestCase):
             request,
             spider=spider,
         )
-        self.assertEqual(new_request, None)
+        assert new_request is None
 
     def test_max_retry_times_meta(self):
         max_retry_times = 0
@@ -429,7 +429,7 @@ class GetRetryRequestTest(unittest.TestCase):
             request,
             spider=spider,
         )
-        self.assertEqual(new_request, None)
+        assert new_request is None
 
     def test_max_retry_times_argument(self):
         max_retry_times = 0
@@ -441,7 +441,7 @@ class GetRetryRequestTest(unittest.TestCase):
             spider=spider,
             max_retry_times=max_retry_times,
         )
-        self.assertEqual(new_request, None)
+        assert new_request is None
 
     def test_priority_adjust_setting(self):
         priority_adjust = 1
@@ -451,7 +451,7 @@ class GetRetryRequestTest(unittest.TestCase):
             request,
             spider=spider,
         )
-        self.assertEqual(new_request.priority, priority_adjust)
+        assert new_request.priority == priority_adjust
 
     def test_priority_adjust_argument(self):
         priority_adjust = 1
@@ -462,7 +462,7 @@ class GetRetryRequestTest(unittest.TestCase):
             spider=spider,
             priority_adjust=priority_adjust,
         )
-        self.assertEqual(new_request.priority, priority_adjust)
+        assert new_request.priority == priority_adjust
 
     def test_log_extra_retry_success(self):
         request = Request("https://example.com")
@@ -497,7 +497,7 @@ class GetRetryRequestTest(unittest.TestCase):
             )
         expected_retry_times = 1
         for stat in ("retry/count", f"retry/reason_count/{expected_reason}"):
-            self.assertEqual(spider.crawler.stats.get_value(stat), 1)
+            assert spider.crawler.stats.get_value(stat) == 1
         log.check_present(
             (
                 "scrapy.downloadermiddlewares.retry",
@@ -522,7 +522,7 @@ class GetRetryRequestTest(unittest.TestCase):
         stat = spider.crawler.stats.get_value(
             f"retry/reason_count/{expected_reason_string}"
         )
-        self.assertEqual(stat, 1)
+        assert stat == 1
         log.check_present(
             (
                 "scrapy.downloadermiddlewares.retry",
@@ -547,7 +547,7 @@ class GetRetryRequestTest(unittest.TestCase):
         stat = spider.crawler.stats.get_value(
             f"retry/reason_count/{expected_reason_string}"
         )
-        self.assertEqual(stat, 1)
+        assert stat == 1
         log.check_present(
             (
                 "scrapy.downloadermiddlewares.retry",
@@ -572,7 +572,7 @@ class GetRetryRequestTest(unittest.TestCase):
         stat = spider.crawler.stats.get_value(
             f"retry/reason_count/{expected_reason_string}"
         )
-        self.assertEqual(stat, 1)
+        assert stat == 1
         log.check_present(
             (
                 "scrapy.downloadermiddlewares.retry",
@@ -597,7 +597,7 @@ class GetRetryRequestTest(unittest.TestCase):
         stat = spider.crawler.stats.get_value(
             f"retry/reason_count/{expected_reason_string}"
         )
-        self.assertEqual(stat, 1)
+        assert stat == 1
         log.check_present(
             (
                 "scrapy.downloadermiddlewares.retry",
@@ -642,8 +642,4 @@ class GetRetryRequestTest(unittest.TestCase):
             f"{stats_key}/count",
             f"{stats_key}/reason_count/{expected_reason}",
         ):
-            self.assertEqual(spider.crawler.stats.get_value(stat), 1)
-
-
-if __name__ == "__main__":
-    unittest.main()
+            assert spider.crawler.stats.get_value(stat) == 1
