@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 import datetime
-import typing
 import unittest
+from typing import Any, Callable
 
-from scrapy.crawler import Crawler
 from scrapy.extensions.periodic_log import PeriodicLog
+from scrapy.utils.test import get_crawler
 
 from .spiders import MetaSpider
 
@@ -51,7 +53,7 @@ stats_dump_2 = {
 }
 
 
-class TestExtPeriodicLog(PeriodicLog):
+class CustomPeriodicLog(PeriodicLog):
     def set_a(self):
         self.stats._stats = stats_dump_1
 
@@ -59,10 +61,9 @@ class TestExtPeriodicLog(PeriodicLog):
         self.stats._stats = stats_dump_2
 
 
-def extension(settings=None):
-    crawler = Crawler(MetaSpider, settings=settings)
-    crawler._apply_settings()
-    return TestExtPeriodicLog.from_crawler(crawler)
+def extension(settings: dict[str, Any] | None = None) -> CustomPeriodicLog:
+    crawler = get_crawler(MetaSpider, settings)
+    return CustomPeriodicLog.from_crawler(crawler)
 
 
 class TestPeriodicLog(unittest.TestCase):
@@ -94,7 +95,7 @@ class TestPeriodicLog(unittest.TestCase):
             ext.spider_closed(spider, reason="finished")
             return ext, a, b
 
-        def check(settings: dict, condition: typing.Callable):
+        def check(settings: dict[str, Any], condition: Callable) -> None:
             ext, a, b = emulate(settings)
             assert list(a["delta"].keys()) == [
                 k for k, v in ext.stats._stats.items() if condition(k, v)
@@ -151,7 +152,7 @@ class TestPeriodicLog(unittest.TestCase):
             ext.spider_closed(spider, reason="finished")
             return ext, a, b
 
-        def check(settings: dict, condition: typing.Callable):
+        def check(settings: dict[str, Any], condition: Callable) -> None:
             ext, a, b = emulate(settings)
             assert list(a["stats"].keys()) == [
                 k for k, v in ext.stats._stats.items() if condition(k, v)
@@ -192,4 +193,3 @@ class TestPeriodicLog(unittest.TestCase):
             {"PERIODIC_LOG_STATS": {"include": ["downloader/"], "exclude": ["bytes"]}},
             lambda k, v: "downloader/" in k and "bytes" not in k,
         )
-        #
