@@ -1,9 +1,10 @@
-import unittest
+import logging
 
+import pytest
 from testfixtures import LogCapture
 from twisted.internet import defer
 from twisted.python.failure import Failure
-from twisted.trial.unittest import TestCase as TwistedTestCase
+from twisted.trial.unittest import TestCase
 
 from scrapy.exceptions import DropItem
 from scrapy.http import Request, Response
@@ -22,19 +23,18 @@ class CustomItem(Item):
         return f"name: {self['name']}"
 
 
-class LogFormatterTestCase(unittest.TestCase):
-    def setUp(self):
+class TestLogFormatter:
+    def setup_method(self):
         self.formatter = LogFormatter()
         self.spider = Spider("default")
+        self.spider.crawler = get_crawler()
 
     def test_crawled_with_referer(self):
         req = Request("http://www.example.com")
         res = Response("http://www.example.com")
         logkws = self.formatter.crawled(req, res, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline, "Crawled (200) <GET http://www.example.com> (referer: None)"
-        )
+        assert logline == "Crawled (200) <GET http://www.example.com> (referer: None)"
 
     def test_crawled_without_referer(self):
         req = Request(
@@ -43,9 +43,9 @@ class LogFormatterTestCase(unittest.TestCase):
         res = Response("http://www.example.com", flags=["cached"])
         logkws = self.formatter.crawled(req, res, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline,
-            "Crawled (200) <GET http://www.example.com> (referer: http://example.com) ['cached']",
+        assert (
+            logline
+            == "Crawled (200) <GET http://www.example.com> (referer: http://example.com) ['cached']"
         )
 
     def test_flags_in_request(self):
@@ -53,9 +53,9 @@ class LogFormatterTestCase(unittest.TestCase):
         res = Response("http://www.example.com")
         logkws = self.formatter.crawled(req, res, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline,
-            "Crawled (200) <GET http://www.example.com> ['test', 'flag'] (referer: None)",
+        assert (
+            logline
+            == "Crawled (200) <GET http://www.example.com> ['test', 'flag'] (referer: None)"
         )
 
     def test_dropped(self):
@@ -66,7 +66,63 @@ class LogFormatterTestCase(unittest.TestCase):
         logline = logkws["msg"] % logkws["args"]
         lines = logline.splitlines()
         assert all(isinstance(x, str) for x in lines)
-        self.assertEqual(lines, ["Dropped: \u2018", "{}"])
+        assert lines == ["Dropped: \u2018", "{}"]
+
+    def test_dropitem_default_log_level(self):
+        item = {}
+        exception = DropItem("Test drop")
+        response = Response("http://www.example.com")
+        spider = Spider("foo")
+        spider.crawler = get_crawler(Spider)
+
+        logkws = self.formatter.dropped(item, exception, response, spider)
+        assert logkws["level"] == logging.WARNING
+
+        spider.crawler.settings.frozen = False
+        spider.crawler.settings["DEFAULT_DROPITEM_LOG_LEVEL"] = logging.INFO
+        spider.crawler.settings.frozen = True
+        logkws = self.formatter.dropped(item, exception, response, spider)
+        assert logkws["level"] == logging.INFO
+
+        spider.crawler.settings.frozen = False
+        spider.crawler.settings["DEFAULT_DROPITEM_LOG_LEVEL"] = "INFO"
+        spider.crawler.settings.frozen = True
+        logkws = self.formatter.dropped(item, exception, response, spider)
+        assert logkws["level"] == logging.INFO
+
+        spider.crawler.settings.frozen = False
+        spider.crawler.settings["DEFAULT_DROPITEM_LOG_LEVEL"] = 10
+        spider.crawler.settings.frozen = True
+        logkws = self.formatter.dropped(item, exception, response, spider)
+        assert logkws["level"] == logging.DEBUG
+
+        spider.crawler.settings.frozen = False
+        spider.crawler.settings["DEFAULT_DROPITEM_LOG_LEVEL"] = 0
+        spider.crawler.settings.frozen = True
+        logkws = self.formatter.dropped(item, exception, response, spider)
+        assert logkws["level"] == logging.NOTSET
+
+        unsupported_value = object()
+        spider.crawler.settings.frozen = False
+        spider.crawler.settings["DEFAULT_DROPITEM_LOG_LEVEL"] = unsupported_value
+        spider.crawler.settings.frozen = True
+        logkws = self.formatter.dropped(item, exception, response, spider)
+        assert logkws["level"] == unsupported_value
+
+        with pytest.raises(TypeError):
+            logging.log(logkws["level"], "message")
+
+    def test_dropitem_custom_log_level(self):
+        item = {}
+        response = Response("http://www.example.com")
+
+        exception = DropItem("Test drop", log_level="INFO")
+        logkws = self.formatter.dropped(item, exception, response, self.spider)
+        assert logkws["level"] == logging.INFO
+
+        exception = DropItem("Test drop", log_level="ERROR")
+        logkws = self.formatter.dropped(item, exception, response, self.spider)
+        assert logkws["level"] == logging.ERROR
 
     def test_item_error(self):
         # In practice, the complete traceback is shown by passing the
@@ -76,7 +132,7 @@ class LogFormatterTestCase(unittest.TestCase):
         response = Response("http://www.example.com")
         logkws = self.formatter.item_error(item, exception, response, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(logline, "Error processing {'key': 'value'}")
+        assert logline == "Error processing {'key': 'value'}"
 
     def test_spider_error(self):
         # In practice, the complete traceback is shown by passing the
@@ -88,9 +144,9 @@ class LogFormatterTestCase(unittest.TestCase):
         response = Response("http://www.example.com", request=request)
         logkws = self.formatter.spider_error(failure, request, response, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline,
-            "Spider error processing <GET http://www.example.com> (referer: http://example.org)",
+        assert (
+            logline
+            == "Spider error processing <GET http://www.example.com> (referer: http://example.org)"
         )
 
     def test_download_error_short(self):
@@ -100,7 +156,7 @@ class LogFormatterTestCase(unittest.TestCase):
         request = Request("http://www.example.com")
         logkws = self.formatter.download_error(failure, request, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(logline, "Error downloading <GET http://www.example.com>")
+        assert logline == "Error downloading <GET http://www.example.com>"
 
     def test_download_error_long(self):
         # In practice, the complete traceback is shown by passing the
@@ -111,9 +167,7 @@ class LogFormatterTestCase(unittest.TestCase):
             failure, request, self.spider, "Some message"
         )
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline, "Error downloading <GET http://www.example.com>: Some message"
-        )
+        assert logline == "Error downloading <GET http://www.example.com>: Some message"
 
     def test_scraped(self):
         item = CustomItem()
@@ -123,9 +177,7 @@ class LogFormatterTestCase(unittest.TestCase):
         logline = logkws["msg"] % logkws["args"]
         lines = logline.splitlines()
         assert all(isinstance(x, str) for x in lines)
-        self.assertEqual(
-            lines, ["Scraped from <200 http://www.example.com>", "name: \xa3"]
-        )
+        assert lines == ["Scraped from <200 http://www.example.com>", "name: \xa3"]
 
 
 class LogFormatterSubclass(LogFormatter):
@@ -141,18 +193,19 @@ class LogFormatterSubclass(LogFormatter):
         }
 
 
-class LogformatterSubclassTest(LogFormatterTestCase):
-    def setUp(self):
+class TestLogformatterSubclass(TestLogFormatter):
+    def setup_method(self):
         self.formatter = LogFormatterSubclass()
         self.spider = Spider("default")
+        self.spider.crawler = get_crawler(Spider)
 
     def test_crawled_with_referer(self):
         req = Request("http://www.example.com")
         res = Response("http://www.example.com")
         logkws = self.formatter.crawled(req, res, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline, "Crawled (200) <GET http://www.example.com> (referer: None) []"
+        assert (
+            logline == "Crawled (200) <GET http://www.example.com> (referer: None) []"
         )
 
     def test_crawled_without_referer(self):
@@ -164,9 +217,9 @@ class LogformatterSubclassTest(LogFormatterTestCase):
         res = Response("http://www.example.com")
         logkws = self.formatter.crawled(req, res, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline,
-            "Crawled (200) <GET http://www.example.com> (referer: http://example.com) ['cached']",
+        assert (
+            logline
+            == "Crawled (200) <GET http://www.example.com> (referer: http://example.com) ['cached']"
         )
 
     def test_flags_in_request(self):
@@ -174,9 +227,9 @@ class LogformatterSubclassTest(LogFormatterTestCase):
         res = Response("http://www.example.com")
         logkws = self.formatter.crawled(req, res, self.spider)
         logline = logkws["msg"] % logkws["args"]
-        self.assertEqual(
-            logline,
-            "Crawled (200) <GET http://www.example.com> (referer: None) ['test', 'flag']",
+        assert (
+            logline
+            == "Crawled (200) <GET http://www.example.com> (referer: None) ['test', 'flag']"
         )
 
 
@@ -201,10 +254,17 @@ class DropSomeItemsPipeline:
         self.drop = True
 
 
-class ShowOrSkipMessagesTestCase(TwistedTestCase):
+class TestShowOrSkipMessages(TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.mockserver = MockServer()
+        cls.mockserver.__enter__()
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.mockserver.__exit__(None, None, None)
+
     def setUp(self):
-        self.mockserver = MockServer()
-        self.mockserver.__enter__()
         self.base_settings = {
             "LOG_LEVEL": "DEBUG",
             "ITEM_PIPELINES": {
@@ -212,17 +272,14 @@ class ShowOrSkipMessagesTestCase(TwistedTestCase):
             },
         }
 
-    def tearDown(self):
-        self.mockserver.__exit__(None, None, None)
-
     @defer.inlineCallbacks
     def test_show_messages(self):
         crawler = get_crawler(ItemSpider, self.base_settings)
         with LogCapture() as lc:
             yield crawler.crawl(mockserver=self.mockserver)
-        self.assertIn("Scraped from <200 http://127.0.0.1:", str(lc))
-        self.assertIn("Crawled (200) <GET http://127.0.0.1:", str(lc))
-        self.assertIn("Dropped: Ignoring item", str(lc))
+        assert "Scraped from <200 http://127.0.0.1:" in str(lc)
+        assert "Crawled (200) <GET http://127.0.0.1:" in str(lc)
+        assert "Dropped: Ignoring item" in str(lc)
 
     @defer.inlineCallbacks
     def test_skip_messages(self):
@@ -231,10 +288,6 @@ class ShowOrSkipMessagesTestCase(TwistedTestCase):
         crawler = get_crawler(ItemSpider, settings)
         with LogCapture() as lc:
             yield crawler.crawl(mockserver=self.mockserver)
-        self.assertNotIn("Scraped from <200 http://127.0.0.1:", str(lc))
-        self.assertNotIn("Crawled (200) <GET http://127.0.0.1:", str(lc))
-        self.assertNotIn("Dropped: Ignoring item", str(lc))
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert "Scraped from <200 http://127.0.0.1:" not in str(lc)
+        assert "Crawled (200) <GET http://127.0.0.1:" not in str(lc)
+        assert "Dropped: Ignoring item" not in str(lc)
