@@ -6,6 +6,7 @@ from pathlib import Path
 from subprocess import PIPE, Popen
 from urllib.parse import urlsplit, urlunsplit
 
+import pytest
 from testfixtures import LogCapture
 from twisted.internet import defer
 from twisted.trial.unittest import TestCase
@@ -48,8 +49,7 @@ sys.exit(mitmdump())
         )
         line = self.proc.stdout.readline().decode("utf-8")
         host_port = re.search(r"listening at (?:http://)?([^:]+:\d+)", line).group(1)
-        address = f"http://{self.auth_user}:{self.auth_pass}@{host_port}"
-        return address
+        return f"http://{self.auth_user}:{self.auth_pass}@{host_port}"
 
     def stop(self):
         self.proc.kill()
@@ -62,15 +62,22 @@ def _wrong_credentials(proxy_url):
     return urlunsplit(bad_auth_proxy)
 
 
-class ProxyConnectTestCase(TestCase):
+class TestProxyConnect(TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.mockserver = MockServer()
+        cls.mockserver.__enter__()
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.mockserver.__exit__(None, None, None)
+
     def setUp(self):
         try:
             import mitmproxy  # noqa: F401
         except ImportError:
-            self.skipTest("mitmproxy is not installed")
+            pytest.skip("mitmproxy is not installed")
 
-        self.mockserver = MockServer()
-        self.mockserver.__enter__()
         self._oldenv = os.environ.copy()
 
         self._proxy = MitmProxy()
@@ -79,7 +86,6 @@ class ProxyConnectTestCase(TestCase):
         os.environ["http_proxy"] = proxy_url
 
     def tearDown(self):
-        self.mockserver.__exit__(None, None, None)
         self._proxy.stop()
         os.environ = self._oldenv
 
@@ -108,12 +114,12 @@ class ProxyConnectTestCase(TestCase):
             yield crawler.crawl(seed=request)
         self._assert_got_response_code(200, log)
         echo = json.loads(crawler.spider.meta["responses"][0].text)
-        self.assertTrue("Proxy-Authorization" not in echo["headers"])
+        assert "Proxy-Authorization" not in echo["headers"]
 
     def _assert_got_response_code(self, code, log):
         print(log)
-        self.assertEqual(str(log).count(f"Crawled ({code})"), 1)
+        assert str(log).count(f"Crawled ({code})") == 1
 
     def _assert_got_tunnel_error(self, log):
         print(log)
-        self.assertIn("TunnelError", str(log))
+        assert "TunnelError" in str(log)
