@@ -1,5 +1,4 @@
 import warnings
-from unittest import TestCase
 from urllib.parse import urlparse
 
 from scrapy.http import Request, Response
@@ -8,10 +7,10 @@ from scrapy.spiders import Spider
 from scrapy.utils.test import get_crawler
 
 
-class TestOffsiteMiddleware(TestCase):
-    def setUp(self):
+class TestOffsiteMiddleware:
+    def setup_method(self):
         crawler = get_crawler(Spider)
-        self.spider = crawler._create_spider(**self._get_spiderargs())
+        self.spider = crawler.spider = crawler._create_spider(**self._get_spiderargs())
         self.mw = OffsiteMiddleware.from_crawler(crawler)
         self.mw.spider_opened(self.spider)
 
@@ -29,6 +28,7 @@ class TestOffsiteMiddleware(TestCase):
             Request("http://scrapy.org/1"),
             Request("http://sub.scrapy.org/1"),
             Request("http://offsite.tld/letmepass", dont_filter=True),
+            Request("http://offsite-2.tld/allow", meta={"allow_offsite": True}),
             Request("http://scrapy.test.org/"),
             Request("http://scrapy.test.org:8000/"),
         ]
@@ -45,7 +45,7 @@ class TestOffsiteMiddleware(TestCase):
         reqs = onsite_reqs + offsite_reqs
 
         out = list(self.mw.process_spider_output(res, reqs, self.spider))
-        self.assertEqual(out, onsite_reqs)
+        assert out == onsite_reqs
 
 
 class TestOffsiteMiddleware2(TestOffsiteMiddleware):
@@ -56,7 +56,7 @@ class TestOffsiteMiddleware2(TestOffsiteMiddleware):
         res = Response("http://scrapytest.org")
         reqs = [Request("http://a.com/b.html"), Request("http://b.com/1")]
         out = list(self.mw.process_spider_output(res, reqs, self.spider))
-        self.assertEqual(out, reqs)
+        assert out == reqs
 
 
 class TestOffsiteMiddleware3(TestOffsiteMiddleware2):
@@ -76,7 +76,7 @@ class TestOffsiteMiddleware4(TestOffsiteMiddleware3):
         res = Response("http://scrapytest.org")
         reqs = [Request("http://scrapytest.org/1")]
         out = list(self.mw.process_spider_output(res, reqs, self.spider))
-        self.assertEqual(out, reqs)
+        assert out == reqs
 
 
 class TestOffsiteMiddleware5(TestOffsiteMiddleware4):
