@@ -1,5 +1,4 @@
 import copy
-import unittest
 import warnings
 from collections.abc import Iterator, Mapping, MutableMapping
 
@@ -16,21 +15,19 @@ from scrapy.utils.datatypes import (
 )
 from scrapy.utils.python import garbage_collect
 
-__doctests__ = ["scrapy.utils.datatypes"]
 
-
-class CaseInsensitiveDictMixin:
+class CaseInsensitiveDictBase:
     def test_init_dict(self):
         seq = {"red": 1, "black": 3}
         d = self.dict_class(seq)
-        self.assertEqual(d["red"], 1)
-        self.assertEqual(d["black"], 3)
+        assert d["red"] == 1
+        assert d["black"] == 3
 
     def test_init_pair_sequence(self):
         seq = (("red", 1), ("black", 3))
         d = self.dict_class(seq)
-        self.assertEqual(d["red"], 1)
-        self.assertEqual(d["black"], 3)
+        assert d["red"] == 1
+        assert d["black"] == 3
 
     def test_init_mapping(self):
         class MyMapping(Mapping):
@@ -48,8 +45,8 @@ class CaseInsensitiveDictMixin:
 
         seq = MyMapping(red=1, black=3)
         d = self.dict_class(seq)
-        self.assertEqual(d["red"], 1)
-        self.assertEqual(d["black"], 3)
+        assert d["red"] == 1
+        assert d["black"] == 3
 
     def test_init_mutable_mapping(self):
         class MyMutableMapping(MutableMapping):
@@ -73,63 +70,65 @@ class CaseInsensitiveDictMixin:
 
         seq = MyMutableMapping(red=1, black=3)
         d = self.dict_class(seq)
-        self.assertEqual(d["red"], 1)
-        self.assertEqual(d["black"], 3)
+        assert d["red"] == 1
+        assert d["black"] == 3
 
     def test_caseless(self):
         d = self.dict_class()
         d["key_Lower"] = 1
-        self.assertEqual(d["KEy_loWer"], 1)
-        self.assertEqual(d.get("KEy_loWer"), 1)
+        assert d["KEy_loWer"] == 1
+        assert d.get("KEy_loWer") == 1
 
         d["KEY_LOWER"] = 3
-        self.assertEqual(d["key_Lower"], 3)
-        self.assertEqual(d.get("key_Lower"), 3)
+        assert d["key_Lower"] == 3
+        assert d.get("key_Lower") == 3
 
     def test_delete(self):
         d = self.dict_class({"key_lower": 1})
         del d["key_LOWER"]
-        self.assertRaises(KeyError, d.__getitem__, "key_LOWER")
-        self.assertRaises(KeyError, d.__getitem__, "key_lower")
+        with pytest.raises(KeyError):
+            d["key_LOWER"]
+        with pytest.raises(KeyError):
+            d["key_lower"]
 
     @pytest.mark.filterwarnings("ignore::scrapy.exceptions.ScrapyDeprecationWarning")
     def test_getdefault(self):
         d = CaselessDict()
-        self.assertEqual(d.get("c", 5), 5)
+        assert d.get("c", 5) == 5
         d["c"] = 10
-        self.assertEqual(d.get("c", 5), 10)
+        assert d.get("c", 5) == 10
 
     @pytest.mark.filterwarnings("ignore::scrapy.exceptions.ScrapyDeprecationWarning")
     def test_setdefault(self):
         d = CaselessDict({"a": 1, "b": 2})
 
         r = d.setdefault("A", 5)
-        self.assertEqual(r, 1)
-        self.assertEqual(d["A"], 1)
+        assert r == 1
+        assert d["A"] == 1
 
         r = d.setdefault("c", 5)
-        self.assertEqual(r, 5)
-        self.assertEqual(d["C"], 5)
+        assert r == 5
+        assert d["C"] == 5
 
     def test_fromkeys(self):
         keys = ("a", "b")
 
         d = self.dict_class.fromkeys(keys)
-        self.assertEqual(d["A"], None)
-        self.assertEqual(d["B"], None)
+        assert d["A"] is None
+        assert d["B"] is None
 
         d = self.dict_class.fromkeys(keys, 1)
-        self.assertEqual(d["A"], 1)
-        self.assertEqual(d["B"], 1)
+        assert d["A"] == 1
+        assert d["B"] == 1
 
         instance = self.dict_class()
         d = instance.fromkeys(keys)
-        self.assertEqual(d["A"], None)
-        self.assertEqual(d["B"], None)
+        assert d["A"] is None
+        assert d["B"] is None
 
         d = instance.fromkeys(keys, 1)
-        self.assertEqual(d["A"], 1)
-        self.assertEqual(d["B"], 1)
+        assert d["A"] == 1
+        assert d["B"] == 1
 
     def test_contains(self):
         d = self.dict_class()
@@ -139,8 +138,9 @@ class CaseInsensitiveDictMixin:
     def test_pop(self):
         d = self.dict_class()
         d["a"] = 1
-        self.assertEqual(d.pop("A"), 1)
-        self.assertRaises(KeyError, d.pop, "A")
+        assert d.pop("A") == 1
+        with pytest.raises(KeyError):
+            d.pop("A")
 
     def test_normkey(self):
         class MyDict(self.dict_class):
@@ -151,7 +151,7 @@ class CaseInsensitiveDictMixin:
 
         d = MyDict()
         d["key-one"] = 2
-        self.assertEqual(list(d.keys()), ["Key-One"])
+        assert list(d.keys()) == ["Key-One"]
 
     def test_normvalue(self):
         class MyDict(self.dict_class):
@@ -163,62 +163,60 @@ class CaseInsensitiveDictMixin:
             normvalue = _normvalue  # deprecated CaselessDict class
 
         d = MyDict({"key": 1})
-        self.assertEqual(d["key"], 2)
-        self.assertEqual(d.get("key"), 2)
+        assert d["key"] == 2
+        assert d.get("key") == 2
 
         d = MyDict()
         d["key"] = 1
-        self.assertEqual(d["key"], 2)
-        self.assertEqual(d.get("key"), 2)
+        assert d["key"] == 2
+        assert d.get("key") == 2
 
         d = MyDict()
         d.setdefault("key", 1)
-        self.assertEqual(d["key"], 2)
-        self.assertEqual(d.get("key"), 2)
+        assert d["key"] == 2
+        assert d.get("key") == 2
 
         d = MyDict()
         d.update({"key": 1})
-        self.assertEqual(d["key"], 2)
-        self.assertEqual(d.get("key"), 2)
+        assert d["key"] == 2
+        assert d.get("key") == 2
 
         d = MyDict.fromkeys(("key",), 1)
-        self.assertEqual(d["key"], 2)
-        self.assertEqual(d.get("key"), 2)
+        assert d["key"] == 2
+        assert d.get("key") == 2
 
     def test_copy(self):
         h1 = self.dict_class({"header1": "value"})
         h2 = copy.copy(h1)
         assert isinstance(h2, self.dict_class)
-        self.assertEqual(h1, h2)
-        self.assertEqual(h1.get("header1"), h2.get("header1"))
-        self.assertEqual(h1.get("header1"), h2.get("HEADER1"))
+        assert h1 == h2
+        assert h1.get("header1") == h2.get("header1")
+        assert h1.get("header1") == h2.get("HEADER1")
         h3 = h1.copy()
         assert isinstance(h3, self.dict_class)
-        self.assertEqual(h1, h3)
-        self.assertEqual(h1.get("header1"), h3.get("header1"))
-        self.assertEqual(h1.get("header1"), h3.get("HEADER1"))
+        assert h1 == h3
+        assert h1.get("header1") == h3.get("header1")
+        assert h1.get("header1") == h3.get("HEADER1")
 
 
-class CaseInsensitiveDictTest(CaseInsensitiveDictMixin, unittest.TestCase):
+class TestCaseInsensitiveDict(CaseInsensitiveDictBase):
     dict_class = CaseInsensitiveDict
 
     def test_repr(self):
         d1 = self.dict_class({"foo": "bar"})
-        self.assertEqual(repr(d1), "<CaseInsensitiveDict: {'foo': 'bar'}>")
+        assert repr(d1) == "<CaseInsensitiveDict: {'foo': 'bar'}>"
         d2 = self.dict_class({"AsDf": "QwErTy", "FoO": "bAr"})
-        self.assertEqual(
-            repr(d2), "<CaseInsensitiveDict: {'AsDf': 'QwErTy', 'FoO': 'bAr'}>"
-        )
+        assert repr(d2) == "<CaseInsensitiveDict: {'AsDf': 'QwErTy', 'FoO': 'bAr'}>"
 
     def test_iter(self):
         d = self.dict_class({"AsDf": "QwErTy", "FoO": "bAr"})
         iterkeys = iter(d)
-        self.assertIsInstance(iterkeys, Iterator)
-        self.assertEqual(list(iterkeys), ["AsDf", "FoO"])
+        assert isinstance(iterkeys, Iterator)
+        assert list(iterkeys) == ["AsDf", "FoO"]
 
 
 @pytest.mark.filterwarnings("ignore::scrapy.exceptions.ScrapyDeprecationWarning")
-class CaselessDictTest(CaseInsensitiveDictMixin, unittest.TestCase):
+class TestCaselessDict(CaseInsensitiveDictBase):
     dict_class = CaselessDict
 
     def test_deprecation_message(self):
@@ -226,93 +224,93 @@ class CaselessDictTest(CaseInsensitiveDictMixin, unittest.TestCase):
             warnings.filterwarnings("always", category=ScrapyDeprecationWarning)
             self.dict_class({"foo": "bar"})
 
-            self.assertEqual(len(caught), 1)
-            self.assertTrue(issubclass(caught[0].category, ScrapyDeprecationWarning))
-            self.assertEqual(
-                "scrapy.utils.datatypes.CaselessDict is deprecated,"
-                " please use scrapy.utils.datatypes.CaseInsensitiveDict instead",
-                str(caught[0].message),
+            assert len(caught) == 1
+            assert issubclass(caught[0].category, ScrapyDeprecationWarning)
+            assert (
+                str(caught[0].message)
+                == "scrapy.utils.datatypes.CaselessDict is deprecated,"
+                " please use scrapy.utils.datatypes.CaseInsensitiveDict instead"
             )
 
 
-class SequenceExcludeTest(unittest.TestCase):
+class TestSequenceExclude:
     def test_list(self):
         seq = [1, 2, 3]
         d = SequenceExclude(seq)
-        self.assertIn(0, d)
-        self.assertIn(4, d)
-        self.assertNotIn(2, d)
+        assert 0 in d
+        assert 4 in d
+        assert 2 not in d
 
     def test_range(self):
         seq = range(10, 20)
         d = SequenceExclude(seq)
-        self.assertIn(5, d)
-        self.assertIn(20, d)
-        self.assertNotIn(15, d)
+        assert 5 in d
+        assert 20 in d
+        assert 15 not in d
 
     def test_range_step(self):
         seq = range(10, 20, 3)
         d = SequenceExclude(seq)
         are_not_in = [v for v in range(10, 20, 3) if v in d]
-        self.assertEqual([], are_not_in)
+        assert are_not_in == []
 
         are_not_in = [v for v in range(10, 20) if v in d]
-        self.assertEqual([11, 12, 14, 15, 17, 18], are_not_in)
+        assert are_not_in == [11, 12, 14, 15, 17, 18]
 
     def test_string_seq(self):
         seq = "cde"
         d = SequenceExclude(seq)
         chars = "".join(v for v in "abcdefg" if v in d)
-        self.assertEqual("abfg", chars)
+        assert chars == "abfg"
 
     def test_stringset_seq(self):
         seq = set("cde")
         d = SequenceExclude(seq)
         chars = "".join(v for v in "abcdefg" if v in d)
-        self.assertEqual("abfg", chars)
+        assert chars == "abfg"
 
     def test_set(self):
         """Anything that is not in the supplied sequence will evaluate as 'in' the container."""
         seq = {-3, "test", 1.1}
         d = SequenceExclude(seq)
-        self.assertIn(0, d)
-        self.assertIn("foo", d)
-        self.assertIn(3.14, d)
-        self.assertIn(set("bar"), d)
+        assert 0 in d
+        assert "foo" in d
+        assert 3.14 in d
+        assert set("bar") in d
 
         # supplied sequence is a set, so checking for list (non)inclusion fails
-        self.assertRaises(TypeError, (0, 1, 2) in d)
-        self.assertRaises(TypeError, d.__contains__, ["a", "b", "c"])
+        with pytest.raises(TypeError):
+            ["a", "b", "c"] in d  # noqa: B015
 
         for v in [-3, "test", 1.1]:
-            self.assertNotIn(v, d)
+            assert v not in d
 
 
-class LocalCacheTest(unittest.TestCase):
+class TestLocalCache:
     def test_cache_with_limit(self):
         cache = LocalCache(limit=2)
         cache["a"] = 1
         cache["b"] = 2
         cache["c"] = 3
-        self.assertEqual(len(cache), 2)
-        self.assertNotIn("a", cache)
-        self.assertIn("b", cache)
-        self.assertIn("c", cache)
-        self.assertEqual(cache["b"], 2)
-        self.assertEqual(cache["c"], 3)
+        assert len(cache) == 2
+        assert "a" not in cache
+        assert "b" in cache
+        assert "c" in cache
+        assert cache["b"] == 2
+        assert cache["c"] == 3
 
     def test_cache_without_limit(self):
         maximum = 10**4
         cache = LocalCache()
         for x in range(maximum):
             cache[str(x)] = x
-        self.assertEqual(len(cache), maximum)
+        assert len(cache) == maximum
         for x in range(maximum):
-            self.assertIn(str(x), cache)
-            self.assertEqual(cache[str(x)], x)
+            assert str(x) in cache
+            assert cache[str(x)] == x
 
 
-class LocalWeakReferencedCacheTest(unittest.TestCase):
+class TestLocalWeakReferencedCache:
     def test_cache_with_limit(self):
         cache = LocalWeakReferencedCache(limit=2)
         r1 = Request("https://example.org")
@@ -321,19 +319,19 @@ class LocalWeakReferencedCacheTest(unittest.TestCase):
         cache[r1] = 1
         cache[r2] = 2
         cache[r3] = 3
-        self.assertEqual(len(cache), 2)
-        self.assertNotIn(r1, cache)
-        self.assertIn(r2, cache)
-        self.assertIn(r3, cache)
-        self.assertEqual(cache[r1], None)
-        self.assertEqual(cache[r2], 2)
-        self.assertEqual(cache[r3], 3)
+        assert len(cache) == 2
+        assert r1 not in cache
+        assert r2 in cache
+        assert r3 in cache
+        assert cache[r1] is None
+        assert cache[r2] == 2
+        assert cache[r3] == 3
         del r2
 
         # PyPy takes longer to collect dead references
         garbage_collect()
 
-        self.assertEqual(len(cache), 1)
+        assert len(cache) == 1
 
     def test_cache_non_weak_referenceable_objects(self):
         cache = LocalWeakReferencedCache()
@@ -343,10 +341,10 @@ class LocalWeakReferencedCacheTest(unittest.TestCase):
         cache[k1] = 1
         cache[k2] = 2
         cache[k3] = 3
-        self.assertNotIn(k1, cache)
-        self.assertNotIn(k2, cache)
-        self.assertNotIn(k3, cache)
-        self.assertEqual(len(cache), 0)
+        assert k1 not in cache
+        assert k2 not in cache
+        assert k3 not in cache
+        assert len(cache) == 0
 
     def test_cache_without_limit(self):
         max = 10**4
@@ -355,10 +353,10 @@ class LocalWeakReferencedCacheTest(unittest.TestCase):
         for x in range(max):
             refs.append(Request(f"https://example.org/{x}"))
             cache[refs[-1]] = x
-        self.assertEqual(len(cache), max)
+        assert len(cache) == max
         for i, r in enumerate(refs):
-            self.assertIn(r, cache)
-            self.assertEqual(cache[r], i)
+            assert r in cache
+            assert cache[r] == i
         del r  # delete reference to the last object in the list  # pylint: disable=undefined-loop-variable
 
         # delete half of the objects, make sure that is reflected in the cache
@@ -368,11 +366,7 @@ class LocalWeakReferencedCacheTest(unittest.TestCase):
         # PyPy takes longer to collect dead references
         garbage_collect()
 
-        self.assertEqual(len(cache), max // 2)
+        assert len(cache) == max // 2
         for i, r in enumerate(refs):
-            self.assertIn(r, cache)
-            self.assertEqual(cache[r], i)
-
-
-if __name__ == "__main__":
-    unittest.main()
+            assert r in cache
+            assert cache[r] == i
