@@ -1,8 +1,9 @@
 import inspect
-import unittest
 import warnings
 from unittest import mock
 
+import pytest
+
 from scrapy.exceptions import ScrapyDeprecationWarning
 from scrapy.utils.deprecate import create_deprecated_class, update_classpath
 
@@ -19,7 +20,7 @@ class NewName(SomeBaseClass):
     pass
 
 
-class WarnWhenSubclassedTest(unittest.TestCase):
+class TestWarnWhenSubclassed:
     def _mywarnings(self, w, category=MyWarning):
         return [x for x in w if x.category is MyWarning]
 
@@ -28,7 +29,7 @@ class WarnWhenSubclassedTest(unittest.TestCase):
             create_deprecated_class("Deprecated", NewName)
 
         w = self._mywarnings(w)
-        self.assertEqual(w, [])
+        assert w == []
 
     def test_subclassing_warning_message(self):
         Deprecated = create_deprecated_class(
@@ -41,15 +42,14 @@ class WarnWhenSubclassedTest(unittest.TestCase):
                 pass
 
         w = self._mywarnings(w)
-        self.assertEqual(len(w), 1)
-        self.assertEqual(
-            str(w[0].message),
-            "tests.test_utils_deprecate.UserClass inherits from "
+        assert len(w) == 1
+        assert (
+            str(w[0].message) == "tests.test_utils_deprecate.UserClass inherits from "
             "deprecated class tests.test_utils_deprecate.Deprecated, "
             "please inherit from tests.test_utils_deprecate.NewName."
-            " (warning only on first subclass, there may be others)",
+            " (warning only on first subclass, there may be others)"
         )
-        self.assertEqual(w[0].lineno, inspect.getsourcelines(UserClass)[1])
+        assert w[0].lineno == inspect.getsourcelines(UserClass)[1]
 
     def test_custom_class_paths(self):
         Deprecated = create_deprecated_class(
@@ -68,11 +68,11 @@ class WarnWhenSubclassedTest(unittest.TestCase):
             _ = Deprecated()
 
         w = self._mywarnings(w)
-        self.assertEqual(len(w), 2)
-        self.assertIn("foo.NewClass", str(w[0].message))
-        self.assertIn("bar.OldClass", str(w[0].message))
-        self.assertIn("foo.NewClass", str(w[1].message))
-        self.assertIn("bar.OldClass", str(w[1].message))
+        assert len(w) == 2
+        assert "foo.NewClass" in str(w[0].message)
+        assert "bar.OldClass" in str(w[0].message)
+        assert "foo.NewClass" in str(w[1].message)
+        assert "bar.OldClass" in str(w[1].message)
 
     def test_subclassing_warns_only_on_direct_children(self):
         Deprecated = create_deprecated_class(
@@ -88,8 +88,8 @@ class WarnWhenSubclassedTest(unittest.TestCase):
                 pass
 
         w = self._mywarnings(w)
-        self.assertEqual(len(w), 1)
-        self.assertIn("UserClass", str(w[0].message))
+        assert len(w) == 1
+        assert "UserClass" in str(w[0].message)
 
     def test_subclassing_warns_once_by_default(self):
         Deprecated = create_deprecated_class(
@@ -108,8 +108,8 @@ class WarnWhenSubclassedTest(unittest.TestCase):
                 pass
 
         w = self._mywarnings(w)
-        self.assertEqual(len(w), 1)
-        self.assertIn("UserClass", str(w[0].message))
+        assert len(w) == 1
+        assert "UserClass" in str(w[0].message)
 
     def test_warning_on_instance(self):
         Deprecated = create_deprecated_class(
@@ -128,13 +128,12 @@ class WarnWhenSubclassedTest(unittest.TestCase):
             _ = UserClass()  # subclass instances don't warn
 
         w = self._mywarnings(w)
-        self.assertEqual(len(w), 1)
-        self.assertEqual(
-            str(w[0].message),
-            "tests.test_utils_deprecate.Deprecated is deprecated, "
-            "instantiate tests.test_utils_deprecate.NewName instead.",
+        assert len(w) == 1
+        assert (
+            str(w[0].message) == "tests.test_utils_deprecate.Deprecated is deprecated, "
+            "instantiate tests.test_utils_deprecate.NewName instead."
         )
-        self.assertEqual(w[0].lineno, lineno)
+        assert w[0].lineno == lineno
 
     def test_warning_auto_message(self):
         with warnings.catch_warnings(record=True) as w:
@@ -144,8 +143,8 @@ class WarnWhenSubclassedTest(unittest.TestCase):
                 pass
 
         msg = str(w[0].message)
-        self.assertIn("tests.test_utils_deprecate.NewName", msg)
-        self.assertIn("tests.test_utils_deprecate.Deprecated", msg)
+        assert "tests.test_utils_deprecate.NewName" in msg
+        assert "tests.test_utils_deprecate.Deprecated" in msg
 
     def test_issubclass(self):
         with warnings.catch_warnings():
@@ -181,7 +180,8 @@ class WarnWhenSubclassedTest(unittest.TestCase):
         assert not issubclass(OutdatedUserClass1, OutdatedUserClass1a)
         assert not issubclass(OutdatedUserClass1a, OutdatedUserClass1)
 
-        self.assertRaises(TypeError, issubclass, object(), DeprecatedName)
+        with pytest.raises(TypeError):
+            issubclass(object(), DeprecatedName)
 
     def test_isinstance(self):
         with warnings.catch_warnings():
@@ -222,7 +222,7 @@ class WarnWhenSubclassedTest(unittest.TestCase):
             warnings.simplefilter("ignore", ScrapyDeprecationWarning)
             Deprecated = create_deprecated_class("Deprecated", NewName, {"foo": "bar"})
 
-        self.assertEqual(Deprecated.foo, "bar")
+        assert Deprecated.foo == "bar"
 
     def test_deprecate_a_class_with_custom_metaclass(self):
         Meta1 = type("Meta1", (type,), {})
@@ -243,7 +243,7 @@ class WarnWhenSubclassedTest(unittest.TestCase):
             )
 
         w = self._mywarnings(w)
-        self.assertEqual(len(w), 0, str(map(str, w)))
+        assert len(w) == 0, str(map(str, w))
 
         with warnings.catch_warnings(record=True) as w:
             AlsoDeprecated()
@@ -252,21 +252,23 @@ class WarnWhenSubclassedTest(unittest.TestCase):
                 pass
 
         w = self._mywarnings(w)
-        self.assertEqual(len(w), 2)
-        self.assertIn("AlsoDeprecated", str(w[0].message))
-        self.assertIn("foo.Bar", str(w[0].message))
-        self.assertIn("AlsoDeprecated", str(w[1].message))
-        self.assertIn("foo.Bar", str(w[1].message))
+        assert len(w) == 2
+        assert "AlsoDeprecated" in str(w[0].message)
+        assert "foo.Bar" in str(w[0].message)
+        assert "AlsoDeprecated" in str(w[1].message)
+        assert "foo.Bar" in str(w[1].message)
 
     def test_inspect_stack(self):
-        with mock.patch("inspect.stack", side_effect=IndexError):
-            with warnings.catch_warnings(record=True) as w:
-                DeprecatedName = create_deprecated_class("DeprecatedName", NewName)
+        with (
+            mock.patch("inspect.stack", side_effect=IndexError),
+            warnings.catch_warnings(record=True) as w,
+        ):
+            DeprecatedName = create_deprecated_class("DeprecatedName", NewName)
 
-                class SubClass(DeprecatedName):
-                    pass
+            class SubClass(DeprecatedName):
+                pass
 
-        self.assertIn("Error detecting parent module", str(w[0].message))
+        assert "Error detecting parent module" in str(w[0].message)
 
 
 @mock.patch(
@@ -276,27 +278,27 @@ class WarnWhenSubclassedTest(unittest.TestCase):
         ("scrapy.contrib.", "scrapy.extensions."),
     ],
 )
-class UpdateClassPathTest(unittest.TestCase):
+class TestUpdateClassPath:
     def test_old_path_gets_fixed(self):
         with warnings.catch_warnings(record=True) as w:
             output = update_classpath("scrapy.contrib.debug.Debug")
-        self.assertEqual(output, "scrapy.extensions.debug.Debug")
-        self.assertEqual(len(w), 1)
-        self.assertIn("scrapy.contrib.debug.Debug", str(w[0].message))
-        self.assertIn("scrapy.extensions.debug.Debug", str(w[0].message))
+        assert output == "scrapy.extensions.debug.Debug"
+        assert len(w) == 1
+        assert "scrapy.contrib.debug.Debug" in str(w[0].message)
+        assert "scrapy.extensions.debug.Debug" in str(w[0].message)
 
     def test_sorted_replacement(self):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", ScrapyDeprecationWarning)
             output = update_classpath("scrapy.contrib.pipeline.Pipeline")
-        self.assertEqual(output, "scrapy.pipelines.Pipeline")
+        assert output == "scrapy.pipelines.Pipeline"
 
     def test_unmatched_path_stays_the_same(self):
         with warnings.catch_warnings(record=True) as w:
             output = update_classpath("scrapy.unmatched.Path")
-        self.assertEqual(output, "scrapy.unmatched.Path")
-        self.assertEqual(len(w), 0)
+        assert output == "scrapy.unmatched.Path"
+        assert len(w) == 0
 
     def test_returns_nonstring(self):
         for notastring in [None, True, [1, 2, 3], object()]:
-            self.assertEqual(update_classpath(notastring), notastring)
+            assert update_classpath(notastring) == notastring
